==> react_image_annotate_ns_workflow-4.0.7.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React from "react";
import Annotator from "../Annotator";
import OCR_blocks from "../OCRJSON/OCR_blocks";
import image from "./imag_ocr";
export default (function () {
  var _React$useState = React.useState({
      taskDescription: "Annotate each image according to this _markdown_ specification.",
      regionTagList: image.tags,
      regionClsList: image.classification,
      enabledTools: ["select", "create-box", "create-polygon"],
      videoName: "",
      videoTime: "0",
      videoSrc: "http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4",
      images: [{
        src: "https://nsworkflow-dev.s3.ap-south-1.amazonaws.com/KalidoPilotBatch4/10277104_20230228121248_202_1.jpg",
        name: "hot-dogs-1",
        regions: [{
          type: "box",
          x: 0.05425204139724521,
          y: 0.10559630252905851,
          w: 0.10946745562130178,
          h: 0.03328402366863907,
          highlighted: true,
          editingLabels: false,
          color: "#f44336",
          cls: "doctors_name",
          id: "35981860315239755",
          qc_label: true,
          keyframes: "0",
          ocr_value: "Dr. Pradip",
          tags: ["doctors_name"],
          tag_count: 1,
          invalid: true,
          invalid_tag: ["doctors_name"],
          update_user: true
        }]
      }, {
        src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
        name: "bianchi-oltre-xr4"
      }],
      allowComments: false
    }),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    annotatorProps = _React$useState2[0],
    changeAnnotatorProps = _React$useState2[1];
  var isImageMode = image.image_ocr;
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onExit: function onExit(e) {
      return console.log(e);
    },
    column_key: "",
    enabledTools: isImageMode ? ["create-box", "create-polygon", "zoom", "zoom_tool_minus"] : ["select", "zoom", "pan", "create-point", "create-box", "create-polygon", "show-mask", "undo_anntation", "redo_anntation", "create-a-brush", "eraser", "zoom_tool_minus"],
    access_block: ["sku"],
    invaild_show: false,
    showUpdate: !isImageMode,
    rightMenu: !isImageMode,
    isReadingMode: false,
    isImageMode: isImageMode,
    hideSaveNext: isImageMode,
    hideQuery: isImageMode,
    hideSave: isImageMode,
    hideHeader: isImageMode,
    hideHeaderText: isImageMode,
    hideNext: isImageMode,
    hidePrev: isImageMode,
    hideClone: isImageMode,
    hideSettings: isImageMode,
    hideFullScreen: isImageMode,
    handleSubmit: function handleSubmit(state, ocr) {
      return console.log(state, ocr);
    },
    tilte_key: "image_le",
    deleteAnnotationAllow: false,
    annotation_index: 0,
    isMediaLayout: true,
    blocks: OCR_blocks,
    image_ocr_map: [],
    editable_data: image.editable_data,
    lazyBrush: [{
      id: "28885889064608783",
      qc_label: false,
      tool: "pen",
      points: [260.0249123922856, 327.7799944228297, 297.0251640586801, 265.7795745775657, 347.0255041484024, 276.7796490662416, 368.02564698608575, 296.7797845001977, 388.0257830219747, 286.7797167832196],
      brushRadius: 5,
      type: "brush",
      popUp: {
        open: false,
        classification: {
          value: "doctors_name",
          label: "doctors_name"
        },
        tags: [{
          value: "doctors_name",
          label: "doctors_name"
        }]
      },
      color: "rgba(244,67,54,0.5)",
      isPopupShow: true,
      isparent: true,
      isLocked: false,
      isHide: false,
      update_user: false,
      tag_count: 1,
      invalid: true,
      invalid_tag: [{
        value: "doctors_name",
        label: "doctors_name"
      }]
    }],
    customize_data: image.customize_data
  })));
});

==> react_image_annotate_ns_workflow-4.0.8.tgz: package/DemoSite/index.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from "react";
import Annotator from "../Annotator";
import OCR_blocks from "../OCRJSON/OCR_blocks";
import image from "./imag_ocr";
export default (function () {
  var isImageMode = image.image_ocr;
  var _useState = useState(_toConsumableArray(image.customize_data)),
    _useState2 = _slicedToArray(_useState, 2),
    clsCustom = _useState2[0],
    setClsCustom = _useState2[1];
  window.customEntity = function (value) {
    setClsCustom([].concat(_toConsumableArray(clsCustom), [{
      title: value,
      mandatory: "non-mandatory",
      input_type: "textArea",
      description: "",
      default_type: value,
      display_label: value,
      other_default_value: "",
      history_hide: true,
      readonly: true,
      content: null,
      isAnnotation: true
    }]));
  };
  var _React$useState = React.useState({
      taskDescription: "Annotate each image according to this _markdown_ specification.",
      regionTagList: !isImageMode ? image.tags : [],
      regionClsList: image.classification,
      enabledTools: ["select", "create-box", "create-polygon"],
      videoName: "",
      videoTime: "0",
      videoSrc: "http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4",
      images: [{
        src: "https://nsworkflow-dev.s3.ap-south-1.amazonaws.com/KalidoPilotBatch4/10277104_20230228121248_202_1.jpg",
        name: "hot-dogs-1",
        regions: [{
          type: "box",
          x: 0.5058089763972117,
          y: 0.25363825363825365,
          w: 0.18026170967347444,
          h: 0.11434511434511435,
          highlighted: false,
          editingLabels: false,
          color: "#4caf50",
          cls: "doctors_qualification",
          id: "925422441603349",
          qc_label: true,
          keyframes: "0",
          ocr_value: "9.2% DUTTA 44mgs s.clag before dinn before",
          invalid: true
        }]
      }, {
        src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
        name: "bianchi-oltre-xr4"
      }],
      allowComments: false
    }),
    _React$useState2 = _slicedToArray(_React$useState, 2),
    annotatorProps = _React$useState2[0],
    changeAnnotatorProps = _React$useState2[1];
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onExit: function onExit(e) {
      return console.log(e);
    },
    column_key: "",
    enabledTools: isImageMode ? ["create-box", "create-polygon", "zoom", "zoom_tool_minus"] : ["select", "zoom", "pan", "create-point", "create-box", "create-polygon", "show-mask", "undo_anntation", "redo_anntation", "create-a-brush", "eraser", "zoom_tool_minus"],
    access_block: ["sku"],
    invalid_show: true,
    showUpdate: !isImageMode,
    rightMenu: !isImageMode,
    isReadingMode: false,
    isImageMode: isImageMode,
    hideSaveNext: isImageMode,
    hideQuery: isImageMode,
    hideSave: isImageMode,
    hideHeader: isImageMode,
    hideHeaderText: isImageMode,
    hideNext: isImageMode,
    hidePrev: isImageMode,
    hideClone: isImageMode,
    hideSettings: isImageMode,
    hideFullScreen: isImageMode,
    handleSubmit: function handleSubmit(state, ocr) {
      return console.log(state, ocr);
    },
    tilte_key: "image_le",
    deleteAnnotationAllow: false,
    annotation_index: 0,
    isMediaLayout: true,
    blocks: OCR_blocks,
    image_ocr_map: [],
    editable_data: image.editable_data,
    invalidForm: ["patient_name", "doctors_name", "prescription_visit_date", "custom2", "custom1"],
    lazyBrush: !isImageMode ? [{
      id: "28885889064608783",
      qc_label: false,
      tool: "pen",
      points: [260.0249123922856, 327.7799944228297, 297.0251640586801, 265.7795745775657, 347.0255041484024, 276.7796490662416, 368.02564698608575, 296.7797845001977, 388.0257830219747, 286.7797167832196],
      brushRadius: 5,
      type: "brush",
      popUp: {
        open: false,
        classification: {
          value: "doctors_name",
          label: "doctors_name"
        },
        tags: [{
          value: "doctors_name",
          label: "doctors_name"
        }]
      },
      color: "rgba(244,67,54,0.5)",
      isPopupShow: true,
      isparent: true,
      isLocked: false,
      isHide: false,
      update_user: false,
      tag_count: 1,
      invalid: true,
      invalid_tag: [{
        value: "doctors_name",
        label: "doctors_name"
      }]
    }] : [],
    customize_data: clsCustom,
    original_data: {
      patient_name: "Hello",
      doctors_name: "Wello",
      prescription_visit_date: "",
      custom2: ["checkbox", "checkbox2"],
      custom1: "radio3"
    }
  })));
});
